pub struct ProgramConfigInit {
pub program_config: Pubkey,
pub initializer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for ProgramConfigInit.
Fields
program_config: Pubkeyinitializer: PubkeyThe hard-coded account that is used to initialize the program config once.
system_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ProgramConfigInitwhere
Pubkey: BorshSerialize,
impl BorshSerialize for ProgramConfigInitwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for ProgramConfigInit
impl ToAccountMetas for ProgramConfigInit
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ProgramConfigInit
impl RefUnwindSafe for ProgramConfigInit
impl Send for ProgramConfigInit
impl Sync for ProgramConfigInit
impl Unpin for ProgramConfigInit
impl UnsafeUnpin for ProgramConfigInit
impl UnwindSafe for ProgramConfigInit