pub struct TransactionBufferCreate {
pub multisig: Pubkey,
pub transaction_buffer: Pubkey,
pub creator: Pubkey,
pub rent_payer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for TransactionBufferCreate.
Fields
multisig: Pubkeytransaction_buffer: Pubkeycreator: PubkeyThe member of the multisig that is creating the transaction.
rent_payer: PubkeyThe payer for the transaction account rent.
system_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for TransactionBufferCreatewhere
Pubkey: BorshSerialize,
impl BorshSerialize for TransactionBufferCreatewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for TransactionBufferCreate
impl ToAccountMetas for TransactionBufferCreate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for TransactionBufferCreate
impl RefUnwindSafe for TransactionBufferCreate
impl Send for TransactionBufferCreate
impl Sync for TransactionBufferCreate
impl Unpin for TransactionBufferCreate
impl UnsafeUnpin for TransactionBufferCreate
impl UnwindSafe for TransactionBufferCreate