pub struct VaultTransactionCreateFromBuffer {
pub vault_transaction_create: VaultTransactionCreate,
pub transaction_buffer: Pubkey,
pub creator: Pubkey,
}Expand description
Generated client accounts for VaultTransactionCreateFromBuffer.
Fields
vault_transaction_create: VaultTransactionCreatetransaction_buffer: Pubkeycreator: PubkeyTrait Implementations
Sourceimpl ToAccountMetas for VaultTransactionCreateFromBuffer
impl ToAccountMetas for VaultTransactionCreateFromBuffer
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for VaultTransactionCreateFromBuffer
impl RefUnwindSafe for VaultTransactionCreateFromBuffer
impl Send for VaultTransactionCreateFromBuffer
impl Sync for VaultTransactionCreateFromBuffer
impl Unpin for VaultTransactionCreateFromBuffer
impl UnsafeUnpin for VaultTransactionCreateFromBuffer
impl UnwindSafe for VaultTransactionCreateFromBuffer