pub struct ConfigTransactionCreate {
pub args: ConfigTransactionCreateArgs,
}Expand description
Instruction.
Fields
args: ConfigTransactionCreateArgsTrait Implementations
Sourceimpl BorshDeserialize for ConfigTransactionCreate
impl BorshDeserialize for ConfigTransactionCreate
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for ConfigTransactionCreate
impl Discriminator for ConfigTransactionCreate
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more