pub struct MultisigSetTimeLock {
pub args: MultisigSetTimeLockArgs,
}Expand description
Instruction.
Fields
args: MultisigSetTimeLockArgsTrait Implementations
Sourceimpl BorshDeserialize for MultisigSetTimeLock
impl BorshDeserialize for MultisigSetTimeLock
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MultisigSetTimeLock
impl BorshSerialize for MultisigSetTimeLock
Sourceimpl Discriminator for MultisigSetTimeLock
impl Discriminator for MultisigSetTimeLock
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more