pub struct ProposalCancelV2 {
pub args: ProposalVoteArgs,
}Expand description
Instruction.
Fields
args: ProposalVoteArgsTrait Implementations
Sourceimpl BorshDeserialize for ProposalCancelV2where
ProposalVoteArgs: BorshDeserialize,
impl BorshDeserialize for ProposalCancelV2where
ProposalVoteArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ProposalCancelV2where
ProposalVoteArgs: BorshSerialize,
impl BorshSerialize for ProposalCancelV2where
ProposalVoteArgs: BorshSerialize,
Sourceimpl Discriminator for ProposalCancelV2
impl Discriminator for ProposalCancelV2
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for ProposalCancelV2
impl InstructionData for ProposalCancelV2