pub struct BatchAddTransactionArgs {
pub ephemeral_signers: u8,
pub transaction_message: Vec<u8>,
}Fields
ephemeral_signers: u8Number of ephemeral signing PDAs required by the transaction.
transaction_message: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for BatchAddTransactionArgs
impl BorshDeserialize for BatchAddTransactionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,