pub struct ConfigTransactionAccountsCloseBumps {
pub proposal: u8,
}Fields
proposal: u8Trait Implementations
Sourceimpl<'info> Accounts<'info, ConfigTransactionAccountsCloseBumps> for ConfigTransactionAccountsClose<'info>where
'info: 'info,
impl<'info> Accounts<'info, ConfigTransactionAccountsCloseBumps> for ConfigTransactionAccountsClose<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut ConfigTransactionAccountsCloseBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut ConfigTransactionAccountsCloseBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreAuto Trait Implementations
impl Freeze for ConfigTransactionAccountsCloseBumps
impl RefUnwindSafe for ConfigTransactionAccountsCloseBumps
impl Send for ConfigTransactionAccountsCloseBumps
impl Sync for ConfigTransactionAccountsCloseBumps
impl Unpin for ConfigTransactionAccountsCloseBumps
impl UnsafeUnpin for ConfigTransactionAccountsCloseBumps
impl UnwindSafe for ConfigTransactionAccountsCloseBumps