pub struct MultisigAddSpendingLimitArgs {
pub create_key: Pubkey,
pub vault_index: u8,
pub mint: Pubkey,
pub amount: u64,
pub period: Period,
pub members: Vec<Pubkey>,
pub destinations: Vec<Pubkey>,
pub memo: Option<String>,
}Fields
create_key: PubkeyKey that is used to seed the SpendingLimit PDA.
vault_index: u8The index of the vault that the spending limit is for.
mint: PubkeyThe token mint the spending limit is for.
amount: u64The amount of tokens that can be spent in a period.
This amount is in decimals of the mint,
so 1 SOL would be 1_000_000_000 and 1 USDC would be 1_000_000.
period: PeriodThe reset period of the spending limit.
When it passes, the remaining amount is reset, unless it’s Period::OneTime.
members: Vec<Pubkey>Members of the Spending Limit that can use it. Don’t have to be members of the multisig.
destinations: Vec<Pubkey>The destination addresses the spending limit is allowed to sent funds to. If empty, funds can be sent to any address.
memo: Option<String>Memo is used for indexing only.