pub struct MultisigCreateArgsV2 {
pub config_authority: Option<Pubkey>,
pub threshold: u16,
pub members: Vec<Member>,
pub time_lock: u32,
pub rent_collector: Option<Pubkey>,
pub memo: Option<String>,
}Fields
The authority that can configure the multisig: add/remove members, change the threshold, etc.
Should be set to None for autonomous multisigs.
threshold: u16The number of signatures required to execute a transaction.
members: Vec<Member>The members of the multisig.
time_lock: u32How many seconds must pass between transaction voting, settlement, and execution.
rent_collector: Option<Pubkey>The address where the rent for the accounts related to executed, rejected, or cancelled
transactions can be reclaimed. If set to None, the rent reclamation feature is turned off.
memo: Option<String>Memo is used for indexing only.