pub struct ProgramConfigInitArgs {
pub authority: Pubkey,
pub multisig_creation_fee: u64,
pub treasury: Pubkey,
}Fields
The authority that can configure the program config: change the treasury, etc.
multisig_creation_fee: u64The fee that is charged for creating a new multisig.
treasury: PubkeyThe treasury where the creation fee is transferred to.