pub struct TransactionBufferCloseBumps {
pub transaction_buffer: u8,
}Fields
transaction_buffer: u8Trait Implementations
Sourceimpl<'info> Accounts<'info, TransactionBufferCloseBumps> for TransactionBufferClose<'info>where
'info: 'info,
impl<'info> Accounts<'info, TransactionBufferCloseBumps> for TransactionBufferClose<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut TransactionBufferCloseBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut TransactionBufferCloseBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreSourceimpl Debug for TransactionBufferCloseBumps
impl Debug for TransactionBufferCloseBumps