pub struct VaultTransactionCreateArgs {
pub vault_index: u8,
pub ephemeral_signers: u8,
pub transaction_message: Vec<u8>,
pub memo: Option<String>,
}Fields
vault_index: u8Index of the vault this transaction belongs to.
ephemeral_signers: u8Number of ephemeral signing PDAs required by the transaction.
transaction_message: Vec<u8>memo: Option<String>Trait Implementations
Sourceimpl BorshDeserialize for VaultTransactionCreateArgs
impl BorshDeserialize for VaultTransactionCreateArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,