Module squads_multisig_program

Module squads_multisig_program 

Functions

batch_accounts_close
Closes Batch and the corresponding Proposal accounts for proposals in terminal states: Executed, Rejected, or Cancelled or stale proposals that aren’t Approved.
batch_add_transaction
Add a transaction to the batch.
batch_create
Create a new batch.
batch_execute_transaction
Execute a transaction from the batch.
config_transaction_accounts_close
Closes a ConfigTransaction and the corresponding Proposal. transaction can be closed if either:
config_transaction_create
Create a new config transaction.
config_transaction_execute
Execute a config transaction. The transaction must be Approved.
multisig_add_member
Add a new member to the controlled multisig.
multisig_add_spending_limit
Create a new spending limit for the controlled multisig.
multisig_change_threshold
Set the threshold config parameter for the controlled multisig.
multisig_create
Create a multisig.
multisig_create_v2
Create a multisig.
multisig_remove_member
Remove a member/key from the controlled multisig.
multisig_remove_spending_limit
Remove the spending limit from the controlled multisig.
multisig_set_config_authority
Set the multisig config_authority.
multisig_set_rent_collector
Set the multisig rent_collector.
multisig_set_time_lock
Set the time_lock config parameter for the controlled multisig.
program_config_init
Initialize the program config.
program_config_set_authority
Set the authority parameter of the program config.
program_config_set_multisig_creation_fee
Set the multisig_creation_fee parameter of the program config.
program_config_set_treasury
Set the treasury parameter of the program config.
proposal_activate
Update status of a multisig proposal from Draft to Active.
proposal_approve
Approve a multisig proposal on behalf of the member. The proposal must be Active.
proposal_cancel
Cancel a multisig proposal on behalf of the member. The proposal must be Approved.
proposal_cancel_v2
Cancel a multisig proposal on behalf of the member. The proposal must be Approved. This was introduced to incorporate proper state update, as old multisig members may have lingering votes, and the proposal size may need to be reallocated to accommodate the new amount of cancel votes. The previous implemenation still works if the proposal size is in line with the threshold size.
proposal_create
Create a new multisig proposal.
proposal_reject
Reject a multisig proposal on behalf of the member. The proposal must be Active.
spending_limit_use
Use a spending limit to transfer tokens from a multisig vault to a destination account.
transaction_buffer_close
Close a transaction buffer account.
transaction_buffer_create
Create a transaction buffer account.
transaction_buffer_extend
Extend a transaction buffer account.
vault_batch_transaction_account_close
Closes a VaultBatchTransaction belonging to the batch and proposal. transaction can be closed if either:
vault_transaction_accounts_close
Closes a VaultTransaction and the corresponding Proposal. transaction can be closed if either:
vault_transaction_create
Create a new vault transaction.
vault_transaction_create_from_buffer
Create a new vault transaction from a completed transaction buffer. Finalized buffer hash must match final_buffer_hash
vault_transaction_execute
Execute a vault transaction. The transaction must be Approved.