pub fn spending_limit_use(
ctx: Context<'_, '_, '_, '_, SpendingLimitUse<'_>>,
args: SpendingLimitUseArgs,
) -> Result<()>Expand description
Use a spending limit to transfer tokens from a multisig vault to a destination account.
pub fn spending_limit_use(
ctx: Context<'_, '_, '_, '_, SpendingLimitUse<'_>>,
args: SpendingLimitUseArgs,
) -> Result<()>Use a spending limit to transfer tokens from a multisig vault to a destination account.