Structs
- Batch
- Stores data required for serial execution of a batch of multisig vault transactions. Vault transaction is a transaction that’s executed on behalf of the multisig vault PDA and wraps arbitrary Solana instructions, typically calling into other Solana programs. The transactions themselves are stored in separate PDAs associated with the this account.
- Config
Transaction - Stores data required for execution of a multisig configuration transaction. Config transaction can perform a predefined set of actions on the Multisig PDA, such as adding/removing members, changing the threshold, etc.
- Member
- Multisig
- Multisig
Compiled Instruction - Concise serialization schema for instructions that make up a transaction. Closely mimics the Solana transaction wire format.
- Multisig
Message Address Table Lookup - Address table lookups describe an on-chain address lookup table to use for loading more readonly and writable accounts into a transaction.
- Permissions
- Bitmask for permissions.
- Program
Config - Global program configuration account.
- Proposal
- Stores the data required for tracking the status of a multisig proposal.
Each
Proposalhas a 1:1 association with a transaction account, e.g. aVaultTransactionor aConfigTransaction; the latter can be executed only after theProposalhas been approved and its time lock is released. - Spending
Limit - Transaction
Buffer - Vault
Batch Transaction - Stores data required for execution of one transaction from a batch.
- Vault
Transaction - Stores data required for tracking the voting and execution status of a vault transaction. Vault transaction is a transaction that’s executed on behalf of the multisig vault PDA and wraps arbitrary Solana instructions, typically calling into other Solana programs.
- Vault
Transaction Message
Enums
- Config
Action - Period
- The reset period of the spending limit.
- Permission
- Proposal
Status - The status of a proposal. Each variant wraps a timestamp of when the status was set.