Functions
- batch_
accounts_ close - Closes Batch and the corresponding Proposal accounts for proposals in terminal states:
Executed,Rejected, orCancelledor stale proposals that aren’tApproved. - batch_
add_ transaction - Add a transaction to the batch.
- batch_
create - Create a new batch.
- batch_
execute_ transaction - Execute a transaction from the batch.
- config_
transaction_ accounts_ close - Closes a
ConfigTransactionand the correspondingProposal.transactioncan be closed if either: - config_
transaction_ create - Create a new config transaction.
- config_
transaction_ execute - Execute a config transaction.
The transaction must be
Approved. - multisig_
add_ member - Add a new member to the controlled multisig.
- multisig_
add_ spending_ limit - Create a new spending limit for the controlled multisig.
- multisig_
change_ threshold - Set the
thresholdconfig parameter for the controlled multisig. - multisig_
create - Create a multisig.
- multisig_
create_ v2 - Create a multisig.
- multisig_
remove_ member - Remove a member/key from the controlled multisig.
- multisig_
remove_ spending_ limit - Remove the spending limit from the controlled multisig.
- multisig_
set_ config_ authority - Set the multisig
config_authority. - multisig_
set_ rent_ collector - Set the multisig
rent_collector. - multisig_
set_ time_ lock - Set the
time_lockconfig parameter for the controlled multisig. - program_
config_ init - Initialize the program config.
- program_
config_ set_ authority - Set the
authorityparameter of the program config. - program_
config_ set_ multisig_ creation_ fee - Set the
multisig_creation_feeparameter of the program config. - program_
config_ set_ treasury - Set the
treasuryparameter of the program config. - proposal_
activate - Update status of a multisig proposal from
DrafttoActive. - proposal_
approve - Approve a multisig proposal on behalf of the
member. The proposal must beActive. - proposal_
cancel - Cancel a multisig proposal on behalf of the
member. The proposal must beApproved. - proposal_
cancel_ v2 - Cancel a multisig proposal on behalf of the
member. The proposal must beApproved. This was introduced to incorporate proper state update, as old multisig members may have lingering votes, and the proposal size may need to be reallocated to accommodate the new amount of cancel votes. The previous implemenation still works if the proposal size is in line with the threshold size. - proposal_
create - Create a new multisig proposal.
- proposal_
reject - Reject a multisig proposal on behalf of the
member. The proposal must beActive. - spending_
limit_ use - Use a spending limit to transfer tokens from a multisig vault to a destination account.
- transaction_
buffer_ close - Close a transaction buffer account.
- transaction_
buffer_ create - Create a transaction buffer account.
- transaction_
buffer_ extend - Extend a transaction buffer account.
- vault_
batch_ transaction_ account_ close - Closes a
VaultBatchTransactionbelonging to thebatchandproposal.transactioncan be closed if either: - vault_
transaction_ accounts_ close - Closes a
VaultTransactionand the correspondingProposal.transactioncan be closed if either: - vault_
transaction_ create - Create a new vault transaction.
- vault_
transaction_ create_ from_ buffer - Create a new vault transaction from a completed transaction buffer.
Finalized buffer hash must match
final_buffer_hash - vault_
transaction_ execute - Execute a vault transaction.
The transaction must be
Approved.